Description Usage Arguments See Also
This function creates a LuminophoR dock using htmlwidgets. The widget can be rendered on HTML pages generated from R Markdown, Shiny, or other applications.
1 | luminophor(items = NULL, width = "100%", height = "72vh", elementId = NULL)
|
items |
Options for htmlwidget (currently not used in this function) |
width, height |
Fixed width/height for widget (in css units). The default
is NULL, which results in intelligent automatic sizing based on the widget's
container. (currently not used in this function - see
|
elementId |
Use an explicit element ID for the widget (rather than an automatically generated one). Useful if you have other JavaScript that needs to explicitly discover and interact with a specific widget instance. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.