Description Usage Arguments Examples
These two functions are like most fooOutput() and renderFoo() functions in the shiny package. The former is used to create an html container for a Lumino dock panel, and the latter is used in the server logic to render the Lumino dock panel.
1 2 3 | luminophorOutput(outputId, width = "100%", height = "auto")
renderLuminophor(expr, env = parent.frame(), quoted = FALSE)
|
outputId |
ID of htmlwidgets container |
width, height |
Must be a valid CSS unit (like |
expr |
An expression to create a Lumino dock htmlwidget (normally
via |
env |
The environment in which to evaluate expr. |
quoted |
Is expr a quoted expression (with |
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 | if (interactive()) {
library(shiny)
library(luminophor)
shinyApp(
ui = fluidPage(
fluidRow(column(12, luminophorOutput('lmo', height='90vh')))
),
server = function(input, output) {
output$lmo <- renderLuminophor(
luminophor() %>%
addWidget("mywidget")
)
}
)
}
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.